16.120. cdist-type__pf_ruleset(7) — cdist 6.9.4 documentation

# 16.120. cdist-type__pf_ruleset(7)

## 16.120.1. NAME

cdist-type__pf_ruleset - Copy a pf(4) ruleset to $__target_host

## 16.120.2. DESCRIPTION

This type is used on *BSD systems to manage the pf firewall's ruleset.

It will also enable and disable the pf firewall as requested in the state parameter.

## 16.120.3. REQUIRED PARAMETERS

state

  Either "absent" (no ruleset at all) or "present", defaults to "present".

## 16.120.4. OPTIONAL PARAMETERS

source

  Required when state is "present". Defines the ruleset to load onto the $__target_host for pf(4).

## 16.120.5. EXAMPLES

    # Remove the current ruleset in place and disable pf
    __pf_ruleset --state absent

    # Enable pf with the ruleset defined in $__manifest/files/pf.conf
    __pf_ruleset --state present --source $__manifest/files/pf.conf

## 16.120.6. SEE ALSO

pf(4)

## 16.120.7. AUTHORS

Kamila Součková <coding--@--kamila.is> Jake Guffey <jake.guffey--@--eprotex.com>

## 16.120.8. COPYING

Copyright (C) 2016 Kamila Součková. Copyright (C) 2012 Jake Guffey. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.